| get_repos | R Documentation |
Pulls data on all repositories for an organization, individual
user or those with a given text in code blobs (with_code parameter) or a
file (with_files parameter) and parse it into table format.
get_repos(
gitstats,
add_contributors = TRUE,
add_languages = TRUE,
with_code = NULL,
in_files = NULL,
with_files = NULL,
language = NULL,
cache = TRUE,
verbose = FALSE,
progress = TRUE,
fill_empty_sha = FALSE
)
gitstats |
A GitStats object. |
add_contributors |
A logical parameter to decide whether to add
information about repositories' contributors to the repositories output
(table). If set to |
add_languages |
A logical, |
with_code |
A character vector, if defined, GitStats will pull repositories with specified code phrases in code blobs. |
in_files |
A character vector of file names. Works when |
with_files |
A character vector, if defined, GitStats will pull repositories with specified files. |
language |
A character. If defined, GitStats will return only repositories with given language. |
cache |
A logical, if set to |
verbose |
A logical, |
progress |
A logical, by default set to |
fill_empty_sha |
A logical, |
A data.frame.
## Not run:
my_gitstats <- create_gitstats() |>
set_github_host(
token = Sys.getenv("GITHUB_PAT"),
orgs = c("r-world-devs", "openpharma")
) |>
set_gitlab_host(
token = Sys.getenv("GITLAB_PAT_PUBLIC"),
orgs = "mbtests"
)
get_repos(my_gitstats)
get_repos(my_gitstats, add_contributors = FALSE)
get_repos(my_gitstats, add_languages = FALSE)
get_repos(my_gitstats, with_code = "Shiny", in_files = "renv.lock")
get_repos(my_gitstats, with_files = "DESCRIPTION")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.