Returns TRUE when mirai daemons are running on the given
GitStats object (i.e. set_parallel() has been called), FALSE
otherwise.
Examples
if (FALSE) { # \dontrun{
my_gitstats <- create_gitstats()
is_parallel(my_gitstats)
} # }
Returns TRUE when mirai daemons are running on the given
GitStats object (i.e. set_parallel() has been called), FALSE
otherwise.
if (FALSE) { # \dontrun{
my_gitstats <- create_gitstats()
is_parallel(my_gitstats)
} # }