remove_from_storage: Remove a table from 'GitStats' storage

View source: R/Storage.R

remove_from_storageR Documentation

Remove a table from GitStats storage

Description

Removes a named table from the active storage backend.

Usage

remove_from_storage(gitstats, storage)

Arguments

gitstats

A GitStats object.

storage

A character, name of the table to remove (e.g. "commits", "repositories").

Value

A GitStats object (invisibly).

Examples

## Not run: 
  my_gitstats <- create_gitstats() |>
    set_github_host(
      token = Sys.getenv("GITHUB_PAT"),
      orgs = "r-world-devs"
    )
  get_commits(my_gitstats, since = "2024-01-01")
  remove_from_storage(my_gitstats, storage = "commits")

## End(Not run)

GitStats documentation built on April 23, 2026, 9:10 a.m.