| set_github_host | R Documentation |
Set GitHub host
set_github_host(
gitstats,
host = NULL,
token = NULL,
orgs = NULL,
repos = NULL,
verbose = is_verbose(gitstats),
.error = TRUE
)
gitstats |
A GitStats object. |
host |
A character, optional, URL name of the host. If not passed, a public host will be used. |
token |
A token. |
orgs |
An optional character vector of organisations |
repos |
An optional character vector of repositories full names (organization and repository name, e.g. "r-world-devs/GitStats"). |
verbose |
A logical, |
.error |
A logical to control if passing wrong input
( |
If you do not define orgs and repos, GitStats will be set to
scan whole Git platform (such as enterprise version of GitHub or GitLab),
unless it is a public platform. In case of a public one (like GitHub) you
need to define orgs or repos as scanning through all organizations may
take large amount of time.
A GitStats object with added information on host.
## Not run:
my_gitstats <- create_gitstats() |>
set_github_host(
orgs = c("r-world-devs", "openpharma", "pharmaverse")
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.