show_orgs: Show organizations set in 'GitStats'

View source: R/GitStats.R

show_orgsR Documentation

Show organizations set in GitStats

Description

Retrieves organizations set or pulled by GitStats. Especially helpful when user is scanning whole git platform and wants to have a glimpse at organizations.

Usage

show_orgs(gitstats)

Arguments

gitstats

A GitStats object.

Value

A vector of organizations.


GitStats documentation built on April 23, 2026, 9:10 a.m.