| remove_from_storage | R Documentation |
GitStats storageRemoves a named table from the active storage backend.
remove_from_storage(gitstats, storage)
gitstats |
A GitStats object. |
storage |
A character, name of the table to remove (e.g. |
A GitStats object (invisibly).
## Not run:
my_gitstats <- create_gitstats() |>
set_github_host(
token = Sys.getenv("GITHUB_PAT"),
orgs = "r-world-devs"
)
get_commits(my_gitstats, since = "2024-01-01")
remove_from_storage(my_gitstats, storage = "commits")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.